import os
import shutil
from elcato.helpers import load_template, loadconfig


def test_setup(name, config_name):
    source = os.path.dirname(os.path.abspath(__file__))
    config_path = os.path.join(source, "fixtures")
    config = loadconfig(config_path, name=config_name)

    path = f"/tmp/elcato/{name}"
    if os.path.exists(path):
        shutil.rmtree(path)
    return path, config




import os
import sys
import json
import helper
from elcato import settings
from elcato.helpers import load_template, loadconfig
from elcato import build_file, build
from elcato.helpers import handle_config


# TODO take out hard coded posts folder
def test_ordering():
    destination, config = helper.test_setup("ordering/", "elcato-json.yaml")
    source = os.path.dirname(os.path.abspath(__file__))
    root = os.path.abspath(f"{source}/../")

    build(root, destination, config)
    assert settings.TEMPLATE is not None
    index_path = f"{destination}index.json"
    with open(index_path, "r") as fp:
        value = json.loads(fp.read())
        assert value.get("title") == "Index"
        assert len(value.get("cards")) == 4
        dates = [p.get("date") for p in value.get("cards")]

        assert dates == [
            " 2018-10-10 12:00:00 UTC",
            " 2018-10-09 12:00:00 UTC",
            " 2018-10-08 12:00:00 UTC",
            " 2017-07-01 12:00:00 UTC",
        ]



import os
import helper
from elcato import settings
from elcato import build_file
from elcato.helpers import handle_config


# TODO take out hard coded posts folder
def test_parse_single_file():
    destination, config = helper.test_setup("parsing/", "elcato.yaml")

    source = os.path.dirname(os.path.abspath(__file__))
    filename = os.path.join(source, "fixtures", "test_document_01_valid.org")
    #handle_config(os.path.join(source, "fixtures", "elcato.yaml"))
    settings.IGNORED_TAGS = ""
    doc = build_file(filename, source, "/tmp/")
    settings.IGNORED_TAGS = "draft"

    assert doc is not None
    assert doc.path == "/posts/fixtures"
    assert doc.relative == "../../"
    assert doc.absolute == "posts/fixtures"
